==> haskell-fdo-notify-0.3.1-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-LA0g280ZULP7FGfCtAjK6r
key:                  fdo-notify-0.3.1-LA0g280ZULP7FGfCtAjK6r
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  9a064e4fa60d2ea7b75ada1ddeef785e
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-8.8.1/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/fdo-notify-0.3.1
hs-libraries:         HSfdo-notify-0.3.1-LA0g280ZULP7FGfCtAjK6r
depends:
    base-4.13.0.0 containers-0.6.2.1 dbus-1.2.7-CyV3G5UyPju6e4c9orJf76

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-94oSXe5vAjWLqIhhvDmmMZ
key:                  fdo-notify-0.3.1-94oSXe5vAjWLqIhhvDmmMZ
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  26c214aaf1dc1ab0a7d2dfa30c908178
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-8.8.1/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/fdo-notify-0.3.1
hs-libraries:         HSfdo-notify-0.3.1-94oSXe5vAjWLqIhhvDmmMZ
depends:
    base-4.13.0.0 containers-0.6.2.1 dbus-1.2.7-9jZkzYRAmAvF1Gh0J27HGk

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
